@@ -110,16 +110,19 @@ _SEQDB = {
     '< CSI 2W'           : 'Ambiguous reporting(MinTTY): treat ambiguous width characters as double width',
     '< CSI ?c'           : 'DA1 Response',
     '< CSI ?1;0c'        : 'DA1 Response: VT100 with no options (could be WizConsole VT100 mode)',
-    '< CSI ?1;2c'        : 'DA1 Response: VT100 with AVO (could be a VT102/rxvt/rxvt-unicode/konsole/kterm/mlterm/iTerm2/tmux/aterm/wterm/Terminal.app(Mac)/mrxvt/MinTTY/TeraTerm/ck/tty.js)',
+    '< CSI ?1;2c'        : 'DA1 Response: VT100 with AVO (could be a VT102/rxvt/rxvt-unicode/konsole/kterm/mlterm/iTerm2/tmux/aterm/wterm/Terminal.app(Mac)/mrxvt/MinTTY/TeraTerm/ck/Poderosa/tty.js)',
     '< CSI ?1;6c'        : 'DA1 Response: VT100 with AVO and GPO (could be MacTerm)',
-    '< CSI ?1;2;4;7c'    : 'DA1 Response: mlterm(3.1.7 or later) with Sixel/DRCS',
+    '< CSI ?1;2;4;7c'    : 'DA1 Response: mlterm(3.1.7 or later) with SIXEL/DRCS',
     '< CSI ?1;2;4c'      : 'DA1 Response: mlterm(3.1.7 or later) with DRCS',
     '< CSI ?6c'          : 'DA1 Response: VT102 (could be linux xvt/console/PuTTY/Terminal.app(GNUStep)/yaft/Cathode/tty.js(linux console mode))',
+    '< CSI ?26c'         : 'DA1 Response: DEC LN03 printer or its alias response',
     '< CSI ?62c'         : 'DA1 Response: VT200 family (could be mosh/WizConsole VT200 mode)',
     '< CSI ?62;9;c'      : 'DA1 Response: VT200 family (could be gnome-terminal)',
+    '< CSI ?63c'         : 'DA1 Response: VT300 family',
     '< CSI ?64;1;2;6;9;15;21;22c': 'DA1 Response: VT400 family (could be xterm pl>=280)',
     '< CSI ?64;1;4;7;9;22;29c': 'DA1 Response: VT400 family (could be tanasinn)',
     '< CSI ?65;1;2;3;4;6;8;9;18;21;22;29;42;44c': 'DA1 Response: VT500 family (could be RLogin)',
+    '< CSI ?73;4;6;8;9;10;11;12;16;18c': 'DA1 Response: DEClaser 2100 printer',
     '< CSI >c'           : 'DA2 Response',
     '< CSI >0;[2]c'      : 'DA2 Response: VT100, Pv=%s, keyboard type=%s',
     '< CSI >0;95;c'      : 'DA2 Response: xterm patch#95 (could be iTerm/iTerm2)',
@@ -137,6 +140,25 @@ _SEQDB = {
     '< CSI >0;277;0c'    : 'DA2 Response: VT100 (could be xterm patch#277 or tanasinn)',
     '< CSI >0;278;0c'    : 'DA2 Response: VT100 (could be xterm patch#278)',
     '< CSI >0;279;0c'    : 'DA2 Response: VT100 (could be xterm patch#279)',
+    '< CSI >0;280;0c'    : 'DA2 Response: VT100 (could be xterm patch#279 with option "-ti vt100")',
+    '< CSI >0;281;0c'    : 'DA2 Response: VT100 (could be xterm patch#279 with option "-ti vt100")',
+    '< CSI >0;282;0c'    : 'DA2 Response: VT100 (could be xterm patch#279 with option "-ti vt100")',
+    '< CSI >0;283;0c'    : 'DA2 Response: VT100 (could be xterm patch#279 with option "-ti vt100")',
+    '< CSI >0;284;0c'    : 'DA2 Response: VT100 (could be xterm patch#279 with option "-ti vt100")',
+    '< CSI >0;285;0c'    : 'DA2 Response: VT100 (could be xterm patch#279 with option "-ti vt100")',
+    '< CSI >0;286;0c'    : 'DA2 Response: VT100 (could be xterm patch#279 with option "-ti vt100")',
+    '< CSI >0;287;0c'    : 'DA2 Response: VT100 (could be xterm patch#279 with option "-ti vt100")',
+    '< CSI >0;288;0c'    : 'DA2 Response: VT100 (could be xterm patch#279 with option "-ti vt100")',
+    '< CSI >0;289;0c'    : 'DA2 Response: VT100 (could be xterm patch#279 with option "-ti vt100")',
+    '< CSI >0;290;0c'    : 'DA2 Response: VT100 (could be xterm patch#279 with option "-ti vt100")',
+    '< CSI >0;291;0c'    : 'DA2 Response: VT100 (could be xterm patch#279 with option "-ti vt100")',
+    '< CSI >0;292;0c'    : 'DA2 Response: VT100 (could be xterm patch#279 with option "-ti vt100")',
+    '< CSI >0;293;0c'    : 'DA2 Response: VT100 (could be xterm patch#279 with option "-ti vt100")',
+    '< CSI >0;294;0c'    : 'DA2 Response: VT100 (could be xterm patch#279 with option "-ti vt100")',
+    '< CSI >0;295;0c'    : 'DA2 Response: VT100 (could be xterm patch#279 with option "-ti vt100")',
+    '< CSI >0;296;0c'    : 'DA2 Response: VT100 (could be xterm patch#279 with option "-ti vt100")',
+    '< CSI >0;297;0c'    : 'DA2 Response: VT100 (could be xterm patch#279 with option "-ti vt100")',
+    '< CSI >0;298;0c'    : 'DA2 Response: VT100 (could be xterm patch#279 with option "-ti vt100")',
     '< CSI >1;[2]c'      : 'DA2 Response: VT220, Pv=%s, keyboard type=%s',
     '< CSI >1;10;0c'     : 'DA2 Response: VT220 (could be mosh/WizConsole VT200 mode)',
     '< CSI >1;96;0c'     : 'DA2 Response: VT220 (could be mlterm)',
@@ -167,6 +189,14 @@ _SEQDB = {
     '< CSI >41;290;0c'   : 'DA2 Response: VT420 (could be xterm patch#290)',
     '< CSI >41;291;0c'   : 'DA2 Response: VT420 (could be xterm patch#291)',
     '< CSI >41;292;0c'   : 'DA2 Response: VT420 (could be xterm patch#292)',
+    '< CSI >41;293;0c'   : 'DA2 Response: VT420 (could be xterm patch#292)',
+    '< CSI >41;294;0c'   : 'DA2 Response: VT420 (could be xterm patch#292)',
+    '< CSI >41;295;0c'   : 'DA2 Response: VT420 (could be xterm patch#292)',
+    '< CSI >41;296;0c'   : 'DA2 Response: VT420 (could be xterm patch#292)',
+    '< CSI >41;297;0c'   : 'DA2 Response: VT420 (could be xterm patch#292)',
+    '< CSI >41;298;0c'   : 'DA2 Response: VT420 (could be xterm patch#292)',
+    '< CSI >46;[3]c'     : 'DA2 Response: DEClaser 2100 printer, firmVer=%s, protocol=%s minorVer=%s',
+    '< CSI >47;[3]c'     : 'DA2 Response: DEClaser 2200 printer, firmVer=%s, protocol=%s minorVer=%s',
     '< CSI >61;[2]c'     : 'DA2 Response: VT510, Pv=%s, keyboard type=%s',
     '< CSI >64;[2]c'     : 'DA2 Response: VT520, Pv=%s, keyboard type=%s',
     '< CSI >65;[2]c'     : 'DA2 Response: VT525, Pv=%s, keyboard type=%s',
@@ -178,6 +208,7 @@ _SEQDB = {
     '< CSI >77;10102;c'  : 'DA2 Response: could be MinTTY 1.1.2',
     '< CSI >77;10103;c'  : 'DA2 Response: could be MinTTY 1.1.3',
     '< CSI >82;[2]c'     : 'DA2 Response: could be mrxvt, Pv=%s, keyboard type=%s',
+    '< CSI >82;1;0c'     : 'DA2 Response: could be Poderosa',
     '< CSI >82;20710;0c' : 'DA2 Response: could be rxvt/ck',
     '< CSI >82;0.5.4;0c' : 'DA2 Response: could be mrxvt 0.5.4',
     '< CSI >83;[2]c'     : 'DA2 Response: could be GNU Screen, Pv=%s, keyboard type=%s',
@@ -493,12 +524,22 @@ _SEQDB = {
     '> CSI ?40h'         : 'DECSET 40 / disallow 80 -> 132 mode',
     '> CSI ?41h'         : 'DECSET 41 / more(1) fix',
     '> CSI ?42h'         : 'DECSET 42 / enable nation replacement character set',
+    '> CSI ?43h'         : 'DECSET 43 / expanded/compressed print mode',
     '> CSI ?44h'         : 'DECSET 44 / turn on margin bell',
     '> CSI ?45h'         : 'DECSET 45 / reverse wraparound mode',
     '> CSI ?46h'         : 'DECSET 46 / start logging',
     '> CSI ?47h'         : 'DECSET 47 / use alternate screen buffer',
-    '> CSI ?66h'         : 'DECSET 66 - DECNKM / application keypad',
+    '> CSI ?51h'         : 'DECSET 51 - DECBWRM / enable black/white reversal mode',
+    '> CSI ?52h'         : 'DECSET 52 - DECOPM / enable origin placement mode',
+    '> CSI ?55h'         : 'DECSET 55 - DECBPM / enable bold page mode',
+    '> CSI ?60h'         : 'DECSET 60 - DECHCCM / enable horizontal cursor-coupling mode',
+    '> CSI ?61h'         : 'DECSET 61 - DECVCCM / enable vertical cursor-coupling mode',
+    '> CSI ?63h'         : 'DECSET 63 - DECPCCM / enable page cursor-coupling mode',
+    '> CSI ?66h'         : 'DECSET 66 - DECNKM / enable application keypad',
+    '> CSI ?67h'         : 'DECSET 67 - DECBKM / enable backarrow key mode',
+    '> CSI ?68h'         : 'DECSET 68 - DECKBUM / use data processing keys',
     '> CSI ?69h'         : 'DECSET 69 - DECLRM / enable left and right margin mode',
+    '> CSI ?80h'         : 'DECSET 80 - DECSDM / enable SIXEL scrolling mode',
     '> CSI ?95h'         : 'DECSET 95 - DECNCSM / do not clear screen when DECCOLM is set/reset',
     '> CSI ?1000h'       : 'DECSET 1000 / enable xterm normal mouse tracking',
     '> CSI ?1001h'       : 'DECSET 1001 / enable highlight mouse tracking',
@@ -550,12 +591,23 @@ _SEQDB = {
     '> CSI ?40l'         : 'DECRST 40 / allow 80 -> 132 mode',
     '> CSI ?41l'         : 'DECRST 41 / no more(1) fix',
     '> CSI ?42l'         : 'DECRST 42 / disable nation replacement character set',
+    '> CSI ?43l'         : 'DECRST 43 / expanded/compressed print mode',
     '> CSI ?44l'         : 'DECRST 44 / turn off margin bell',
     '> CSI ?45l'         : 'DECRST 45 / no reverse wraparound mode',
     '> CSI ?46l'         : 'DECRST 46 / stop logging',
     '> CSI ?47l'         : 'DECRST 47 / use normal screen buffer',
-    '> CSI ?66l'         : 'DECRST 66 - DECNKM / numeric keypad',
+    '> CSI ?51l'         : 'DECRST 51 - DECBWRM / disable black/white reversal mode',
+    '> CSI ?52l'         : 'DECRST 52 - DECOPM / disable origin placement mode',
+    '> CSI ?55l'         : 'DECRST 55 - DECBPM / disable bold page mode',
+    '> CSI ?60l'         : 'DECRST 60 - DECHCCM / disable horizontal cursor-coupling mode',
+    '> CSI ?61l'         : 'DECRST 61 - DECVCCM / disable vertical cursor-coupling mode',
+    '> CSI ?63l'         : 'DECRST 63 - DECPCCM / disable page cursor-coupling mode',
+    '> CSI ?66l'         : 'DECRST 66 - DECNKM / disable numeric keypad',
+    '> CSI ?67l'         : 'DECRST 67 - DECBKM / disable backarrow key mode',
+    '> CSI ?68l'         : 'DECRST 68 - DECKBUM / use typewriter keys',
+
     '> CSI ?69l'         : 'DECRST 69 - DECLRM / disable left and right margin mode',
+    '> CSI ?80l'         : 'DECRST 80 - DECSDM / disable SIXEL scrolling mode',
     '> CSI ?95l'         : 'DECRST 95 - DECNCSM / clear screen when DECCOLM is set/reset',
     '> CSI ?1000l'       : 'DECRST 1000 / disable xterm normal mouse mode',
     '> CSI ?1001l'       : 'DECRST 1001 / disable highlight mouse tracking',
